@@ -17,4 +17,6 @@
 # limitations under the License.
 
 from .unet import UNetModel
-from .unet_glide import UNetGLIDEModel
+from .unet_glide import GLIDESuperResUNetModel, GLIDETextToImageUNetModel, GLIDEUNetModel
+from .unet_grad_tts import UNetGradTTSModel
+from .unet_ldm import UNetLDMModel
